# Copyright (C) 2020  SNAX Authors <https://git.ligo.org/snax/snax/-/blob/main/AUTHORS.md>
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2 of the License, or (at your
# option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

import os
from typing import Optional

import jinja2

from ..config import Config


def write_makefile(
    config: Config, template: str, path: Optional[str] = None, **kwargs
) -> None:
    """Generate a Makefile based on a configuration and template."""
    if not path:
        path = os.getcwd()

    template_loader = jinja2.PackageLoader("snax.workflows", "templates")
    template_env = jinja2.Environment(
        loader=template_loader, trim_blocks=True, lstrip_blocks=True
    )
    template = template_env.get_template(template)

    makefile = template.render(config=config, **kwargs)
    with open(os.path.join(path, "Makefile"), "w") as f:
        f.write(makefile)
